import { Enums, segmentation, utilities } from '@cornerstonejs/tools';
const { getSegmentation } = segmentation.state;
const { validateLabelmap } = utilities.segmentation;
const conversionPaths = new Map([
    [
        Enums.SegmentationRepresentations.Labelmap,
        new Set([
            Enums.SegmentationRepresentations.Surface,
            Enums.SegmentationRepresentations.Contour,
        ]),
    ],
    [
        Enums.SegmentationRepresentations.Contour,
        new Set([
            Enums.SegmentationRepresentations.Labelmap,
            Enums.SegmentationRepresentations.Surface,
        ]),
    ],
    [
        Enums.SegmentationRepresentations.Surface,
        new Set([Enums.SegmentationRepresentations.Labelmap]),
    ],
]);
function canComputeRequestedRepresentation(segmentationId, representationType) {
    const { representationData } = getSegmentation(segmentationId);
    const existingRepresentationTypes = getExistingRepresentationTypes(representationData);
    return existingRepresentationTypes.some((existingRepresentationType) => canConvertFromTo(existingRepresentationType, representationType));
}
function getExistingRepresentationTypes(representationData) {
    const supportedTypes = [];
    Object.keys(representationData).forEach((representationType) => {
        const representationTypeData = representationData[representationType];
        let validateFn;
        switch (representationType) {
            case Enums.SegmentationRepresentations.Labelmap:
                validateFn = validateLabelmap.validate;
                break;
        }
        if (validateFn) {
            try {
                validateFn(representationTypeData);
                supportedTypes.push(representationType);
            }
            catch (error) {
                console.warn(`Validation failed for labelmap of type ${representationType}`);
            }
        }
        else {
            supportedTypes.push(representationType);
        }
    });
    return supportedTypes;
}
async function canConvertFromTo(fromRepresentationType, toRepresentationType) {
    return (conversionPaths.get(fromRepresentationType)?.has(toRepresentationType) ||
        false);
}
export { canComputeRequestedRepresentation };
